/**
 *
 */
package de.intevation.gnv.geobackend.base;

import java.io.Serializable;

/**
 * Interface which provides the Methods for Accessing
 * the MetaData of an ResultEntry
 * @author Tim Englich <tim.englich@intevation.de>
 */
public interface ResultDescriptor extends Serializable{

    /**
     * Returns the Classname of the Column
     * @param column the id of the Column which is requested
     * @return the Classname of the Column
     */
    public String getColumnClassName(int column);

    /**
     * Returns the Number of Columns
     * @return the Number of Columns
     */
    public int getColumnCount();

    /**
     * Returns the Name of the Column which belongs to the given Columnindex
     * @param column the Index of the Column
     * @return the Name of the Column
     */
    public String getColumnName(int column);

    /**
     * Adds a new ColumnDescription into the Descriptor
     * @param name the Name of the Column (unique)
     * @param className the Name of the Class (e.g. Double, Integer
     */
    public void addColumn(String name, String className);

    /**
     * Returns the Indices of the Columns which are specified in the
     * param columnNames.
     * @param columnNames the Name of the Columns for which the Indices should returned.
     * @return the Indices of the Columns which are specified in the
     * param columnNames.
     */
    public int [] getColumnIndices(String [] columnNames);

    /**
     * Returns the index of the given columnName
     * @param columnName the Name of the Index which should be looked up.
     * @return the index of the given columnName
     */
    public int getColumnIndex(String columnName);
}
