/**
 *
 */
package de.intevation.gnv.geobackend.sde.datasources;

import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.Array;
import java.sql.Blob;
import java.sql.Clob;
import java.sql.Date;
import java.sql.NClob;
import java.sql.Ref;
import java.sql.ResultSetMetaData;
import java.sql.RowId;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.SQLXML;
import java.sql.Statement;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import de.intevation.gnv.geobackend.sde.datasources.exception.TechnicalException;

/**
 * SDEResultSet is an Implementation of the Interface @see java.sql.resultSet
 * It is an Wrapper between the resultsets whcih are produced using the ArcSDE 
 * and the Java-Interface for the Representation of ResultSets.
 * @author blume
 * @author Tim Englich <tim.englich@intevation.de>
 */
public class SDEResultSet extends ResultSet {
    
   /**
     * Default Logging instance
     */
    private static Logger log = Logger.getLogger(SDEResultSet.class);
    
    private List<Row> mRows = Collections.synchronizedList(new ArrayList<Row>());
    private List<ColDefinition> mCols = Collections.synchronizedList(new ArrayList<ColDefinition>());
    
    private Row currentRow = null;
    private int cursor = 0;
    
    /**
     * Constructor
     */
    public SDEResultSet() {
    }
    
    /**
     * @see de.intevation.gnv.geobackend.sde.datasources.ResultSet#getCount()
     */
    public int getCount() {
        return mRows.size();
    }
    
    /**
     * @see de.intevation.gnv.geobackend.sde.datasources.ResultSet#getNumberOfColumns()
     */
    public int getNumberOfColumns() {
        return mCols.size();
    }
    
    /**
     * @see de.intevation.gnv.geobackend.sde.datasources.ResultSet#getColumnDefinitions()
     */
    public ColDefinition[] getColumnDefinitions() {
        ColDefinition[] lColDefinitions = new ColDefinition[mCols.size()];
        return mCols.toArray(lColDefinitions);
    }
    
    /**
     * @see de.intevation.gnv.geobackend.sde.datasources.ResultSet#getResults()
     */
    public Row[] getResults() {
        Row[] lRows = new Row[mRows.size()];
        return mRows.toArray(lRows);
    }
    
    /**
     * Add an Row to the Resultset
     * @param pRow The Row that should be added.
     */
    public void addRow(Row pRow) {
        mRows.add(pRow);
    }

    /**
     * Adds a Column to the Resultset.
     * @param pColDefinition The Definition of the Column
     */
    public void addCol(ColDefinition pColDefinition) {
        mCols.add(pColDefinition);
    }
    
    /**
     * @see java.sql.ResultSet#absolute(int)
     */
    public boolean absolute(int row) throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#afterLast()
     */
    public void afterLast() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#beforeFirst()
     */
    public void beforeFirst() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#cancelRowUpdates()
     */
    public void cancelRowUpdates() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#clearWarnings()
     */
    public void clearWarnings() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#close()
     */
    public void close() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#deleteRow()
     */
    public void deleteRow() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#findColumn(java.lang.String)
     */
    public int findColumn(String columnName) throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#first()
     */
    public boolean first() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#getArray(int)
     */
    public Array getArray(int i) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getArray(java.lang.String)
     */
    public Array getArray(String colName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getAsciiStream(int)
     */
    public InputStream getAsciiStream(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getAsciiStream(java.lang.String)
     */
    public InputStream getAsciiStream(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBigDecimal(int)
     */
    public BigDecimal getBigDecimal(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBigDecimal(java.lang.String)
     */
    public BigDecimal getBigDecimal(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBigDecimal(int, int)
     */
    public BigDecimal getBigDecimal(int columnIndex, int scale)
            throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBigDecimal(java.lang.String, int)
     */
    public BigDecimal getBigDecimal(String columnName, int scale)
            throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBinaryStream(int)
     */
    public InputStream getBinaryStream(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBinaryStream(java.lang.String)
     */
    public InputStream getBinaryStream(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBlob(int)
     */
    public Blob getBlob(int i) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBlob(java.lang.String)
     */
    public Blob getBlob(String colName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBoolean(int)
     */
    public boolean getBoolean(int columnIndex) throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#getBoolean(java.lang.String)
     */
    public boolean getBoolean(String columnName) throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#getByte(int)
     */
    public byte getByte(int columnIndex) throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getByte(java.lang.String)
     */
    public byte getByte(String columnName) throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getBytes(int)
     */
    public byte[] getBytes(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getBytes(java.lang.String)
     */
    public byte[] getBytes(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getCharacterStream(int)
     */
    public Reader getCharacterStream(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getCharacterStream(java.lang.String)
     */
    public Reader getCharacterStream(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getClob(int)
     */
    public Clob getClob(int i) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getClob(java.lang.String)
     */
    public Clob getClob(String colName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getConcurrency()
     */
    public int getConcurrency() throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getCursorName()
     */
    public String getCursorName() throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getDate(int)
     */
    public Date getDate(int columnIndex) throws SQLException {
        try {
            return new java.sql.Date(this.currentRow.getDateValue(columnIndex-1).getTime());
        } catch (TechnicalException e) {
            log.error(e,e);
            throw new SQLException(e.getMessage());
        }
    }
    
    /**
     * @see java.sql.ResultSet#getDate(java.lang.String)
     */
    public Date getDate(String columnName) throws SQLException {
        int columnIndex = this.getColumnIndex(columnName);
        return this.getDate(columnIndex);
    }
    
    /**
     * @see java.sql.ResultSet#getDate(int, java.util.Calendar)
     */
    public Date getDate(int columnIndex, Calendar cal) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getDate(java.lang.String, java.util.Calendar)
     */
    public Date getDate(String columnName, Calendar cal) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getDouble(int)
     */
    public double getDouble(int columnIndex) throws SQLException {
        try {
            return this.currentRow.getDoubleValue(columnIndex-1);
        } catch (TechnicalException e) {
            log.error(e,e);
            throw new SQLException(e.getMessage());
        }
    }
    
    /**
     * @see java.sql.ResultSet#getDouble(java.lang.String)
     */
    public double getDouble(String columnName) throws SQLException {
        int columnIndex = this.getColumnIndex(columnName);
        return this.getDouble(columnIndex);
    }
    
    /**
     * @see java.sql.ResultSet#getFetchDirection()
     */
    public int getFetchDirection() throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getFetchSize()
     */
    public int getFetchSize() throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getFloat(int)
     */
    public float getFloat(int columnIndex) throws SQLException {
        try {
            return this.currentRow.getFloatValue(columnIndex-1);
        } catch (TechnicalException e) {
            log.error(e,e);
            throw new SQLException(e.getMessage());
        }
    }
    
    /**
     * @see java.sql.ResultSet#getFloat(java.lang.String)
     */
    public float getFloat(String columnName) throws SQLException {
        int columnIndex = this.getColumnIndex(columnName);
        return this.getFloat(columnIndex);
    }
    
    /**
     * @see java.sql.ResultSet#getInt(int)
     */
    public int getInt(int columnIndex) throws SQLException {
    
        try {
            return this.currentRow.getIntValue(columnIndex-1);
        } catch (TechnicalException e) {
            log.error(e,e);
            throw new SQLException(e.getMessage());
        }
    }
    
    /**
     * @see java.sql.ResultSet#getInt(java.lang.String)
     */
    public int getInt(String columnName) throws SQLException {
        int columnIndex = this.getColumnIndex(columnName);
        return this.getInt(columnIndex);
    }
    
    /**
     * @see java.sql.ResultSet#getLong(int)
     */
    public long getLong(int columnIndex) throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getLong(java.lang.String)
     */
    public long getLong(String columnName) throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getMetaData()
     */
    public ResultSetMetaData getMetaData() throws SQLException {
        log.debug("SDEREsultSet.getMetaData");
        return new ArcSDEResultSetMetaData(this.mCols);
    }
    
    /**
     * @see java.sql.ResultSet#getObject(int)
     */
    public Object getObject(int columnIndex) throws SQLException {
        try {
            return this.currentRow.getValue(columnIndex-1);
        } catch (TechnicalException e) {
            log.error(e,e);
            throw new SQLException(e.getMessage());
        }
    }
    
    /**
     * @see java.sql.ResultSet#getObject(java.lang.String)
     */
    public Object getObject(String columnName) throws SQLException {
        int columnIndex = this.getColumnIndex(columnName);
        return this.getObject(columnIndex);
    }
    
    /**
     * @see java.sql.ResultSet#getObject(int, java.util.Map)
     */
    public Object getObject(int i, Map<String, Class<?>> map)
            throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getObject(java.lang.String, java.util.Map)
     */
    public Object getObject(String colName, Map<String, Class<?>> map)
            throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getRef(int)
     */
    public Ref getRef(int i) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getRef(java.lang.String)
     */
    public Ref getRef(String colName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getRow()
     */
    public int getRow() throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getShort(int)
     */
    public short getShort(int columnIndex) throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getShort(java.lang.String)
     */
    public short getShort(String columnName) throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getStatement()
     */
    public Statement getStatement() throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getString(int)
     */
    public String getString(int columnIndex) throws SQLException {
    
        try {
            return this.currentRow.getStringValue(columnIndex-1);
        } catch (TechnicalException e) {
            log.error(e,e);
            throw new SQLException(e.getMessage());
        }
    }
    
    /**
     * @see java.sql.ResultSet#getString(java.lang.String)
     */
    public String getString(String columnName) throws SQLException {
        int columnIndex = this.getColumnIndex(columnName);
        return this.getString(columnIndex);
    }
    
    /**
     * @see java.sql.ResultSet#getTime(int)
     */
    public Time getTime(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getTime(java.lang.String)
     */
    public Time getTime(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getTime(int, java.util.Calendar)
     */
    public Time getTime(int columnIndex, Calendar cal) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getTime(java.lang.String, java.util.Calendar)
     */
    public Time getTime(String columnName, Calendar cal) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getTimestamp(int)
     */
    public Timestamp getTimestamp(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getTimestamp(java.lang.String)
     */
    public Timestamp getTimestamp(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getTimestamp(int, java.util.Calendar)
     */
    public Timestamp getTimestamp(int columnIndex, Calendar cal)
            throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getTimestamp(java.lang.String,
     *      java.util.Calendar)
     */
    public Timestamp getTimestamp(String columnName, Calendar cal)
            throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getType()
     */
    public int getType() throws SQLException {
    
        return 0;
    }
    
    /**
     * @see java.sql.ResultSet#getURL(int)
     */
    public URL getURL(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getURL(java.lang.String)
     */
    public URL getURL(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getUnicodeStream(int)
     */
    public InputStream getUnicodeStream(int columnIndex) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getUnicodeStream(java.lang.String)
     */
    public InputStream getUnicodeStream(String columnName) throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#getWarnings()
     */
    public SQLWarning getWarnings() throws SQLException {
    
        return null;
    }
    
    /**
     * @see java.sql.ResultSet#insertRow()
     */
    public void insertRow() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#isAfterLast()
     */
    public boolean isAfterLast() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#isBeforeFirst()
     */
    public boolean isBeforeFirst() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#isFirst()
     */
    public boolean isFirst() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#isLast()
     */
    public boolean isLast() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#last()
     */
    public boolean last() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#moveToCurrentRow()
     */
    public void moveToCurrentRow() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#moveToInsertRow()
     */
    public void moveToInsertRow() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#next()
     */
    public boolean next() throws SQLException {
        
        boolean next = this.mRows.size() > this.cursor;
        if (next){
            //log.debug("Zeile "+(cursor+1)+" von "+this.mRows.size()+" wird angesteuert.");
            this.currentRow = this.mRows.get(this.cursor);
            this.cursor++;
        }else{
            this.currentRow = null;
        }
        return next;
    }
    
    /**
     * @see java.sql.ResultSet#previous()
     */
    public boolean previous() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#refreshRow()
     */
    public void refreshRow() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#relative(int)
     */
    public boolean relative(int rows) throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#rowDeleted()
     */
    public boolean rowDeleted() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#rowInserted()
     */
    public boolean rowInserted() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#rowUpdated()
     */
    public boolean rowUpdated() throws SQLException {
    
        return false;
    }
    
    /**
     * @see java.sql.ResultSet#setFetchDirection(int)
     */
    public void setFetchDirection(int direction) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#setFetchSize(int)
     */
    public void setFetchSize(int rows) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateArray(int, java.sql.Array)
     */
    public void updateArray(int columnIndex, Array x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateArray(java.lang.String, java.sql.Array)
     */
    public void updateArray(String columnName, Array x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateAsciiStream(int, java.io.InputStream, int)
     */
    public void updateAsciiStream(int columnIndex, InputStream x, int length)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateAsciiStream(java.lang.String,
     *      java.io.InputStream, int)
     */
    public void updateAsciiStream(String columnName, InputStream x, int length)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBigDecimal(int, java.math.BigDecimal)
     */
    public void updateBigDecimal(int columnIndex, BigDecimal x)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBigDecimal(java.lang.String,
     *      java.math.BigDecimal)
     */
    public void updateBigDecimal(String columnName, BigDecimal x)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBinaryStream(int, java.io.InputStream, int)
     */
    public void updateBinaryStream(int columnIndex, InputStream x, int length)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBinaryStream(java.lang.String,
     *      java.io.InputStream, int)
     */
    public void updateBinaryStream(String columnName, InputStream x, int length)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBlob(int, java.sql.Blob)
     */
    public void updateBlob(int columnIndex, Blob x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBlob(java.lang.String, java.sql.Blob)
     */
    public void updateBlob(String columnName, Blob x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBoolean(int, boolean)
     */
    public void updateBoolean(int columnIndex, boolean x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBoolean(java.lang.String, boolean)
     */
    public void updateBoolean(String columnName, boolean x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateByte(int, byte)
     */
    public void updateByte(int columnIndex, byte x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateByte(java.lang.String, byte)
     */
    public void updateByte(String columnName, byte x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBytes(int, byte[])
     */
    public void updateBytes(int columnIndex, byte[] x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateBytes(java.lang.String, byte[])
     */
    public void updateBytes(String columnName, byte[] x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateCharacterStream(int, java.io.Reader, int)
     */
    public void updateCharacterStream(int columnIndex, Reader x, int length)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateCharacterStream(java.lang.String,
     *      java.io.Reader, int)
     */
    public void updateCharacterStream(String columnName, Reader reader,
            int length) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateClob(int, java.sql.Clob)
     */
    public void updateClob(int columnIndex, Clob x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateClob(java.lang.String, java.sql.Clob)
     */
    public void updateClob(String columnName, Clob x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateDate(int, java.sql.Date)
     */
    public void updateDate(int columnIndex, Date x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateDate(java.lang.String, java.sql.Date)
     */
    public void updateDate(String columnName, Date x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateDouble(int, double)
     */
    public void updateDouble(int columnIndex, double x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateDouble(java.lang.String, double)
     */
    public void updateDouble(String columnName, double x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateFloat(int, float)
     */
    public void updateFloat(int columnIndex, float x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateFloat(java.lang.String, float)
     */
    public void updateFloat(String columnName, float x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateInt(int, int)
     */
    public void updateInt(int columnIndex, int x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateInt(java.lang.String, int)
     */
    public void updateInt(String columnName, int x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateLong(int, long)
     */
    public void updateLong(int columnIndex, long x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateLong(java.lang.String, long)
     */
    public void updateLong(String columnName, long x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateNull(int)
     */
    public void updateNull(int columnIndex) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateNull(java.lang.String)
     */
    public void updateNull(String columnName) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateObject(int, java.lang.Object)
     */
    public void updateObject(int columnIndex, Object x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateObject(java.lang.String, java.lang.Object)
     */
    public void updateObject(String columnName, Object x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateObject(int, java.lang.Object, int)
     */
    public void updateObject(int columnIndex, Object x, int scale)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateObject(java.lang.String, java.lang.Object,
     *      int)
     */
    public void updateObject(String columnName, Object x, int scale)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateRef(int, java.sql.Ref)
     */
    public void updateRef(int columnIndex, Ref x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateRef(java.lang.String, java.sql.Ref)
     */
    public void updateRef(String columnName, Ref x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateRow()
     */
    public void updateRow() throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateShort(int, short)
     */
    public void updateShort(int columnIndex, short x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateShort(java.lang.String, short)
     */
    public void updateShort(String columnName, short x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateString(int, java.lang.String)
     */
    public void updateString(int columnIndex, String x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateString(java.lang.String, java.lang.String)
     */
    public void updateString(String columnName, String x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateTime(int, java.sql.Time)
     */
    public void updateTime(int columnIndex, Time x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateTime(java.lang.String, java.sql.Time)
     */
    public void updateTime(String columnName, Time x) throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateTimestamp(int, java.sql.Timestamp)
     */
    public void updateTimestamp(int columnIndex, Timestamp x)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#updateTimestamp(java.lang.String,
     *      java.sql.Timestamp)
     */
    public void updateTimestamp(String columnName, Timestamp x)
            throws SQLException {
    }
    
    /**
     * @see java.sql.ResultSet#wasNull()
     */
    public boolean wasNull() throws SQLException {
    
            return false;
    }

    /**
     * TODO: DOCUMENT ME
     * @param columnName
     * @return
     * @throws SQLException
     */
    private int getColumnIndex(String columnName) throws SQLException{
        for (int i = 0 ; i < this.mCols.size();i++){
            if(this.mCols.get(i).getName().equalsIgnoreCase(columnName)){
                return i +1; // PLUS 1 da SQL-Cursor 1 basiert sind
            }
        }
        throw new SQLException("Column "+columnName+" does not exist in ResulSet");
    }

    /**
     * @see java.sql.ResultSet#getHoldability()
     */
    public int getHoldability() throws SQLException {
        return 0;
    }

    /**
     * @see java.sql.ResultSet#getNCharacterStream(int)
     */
    public Reader getNCharacterStream(int arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getNCharacterStream(java.lang.String)
     */
    public Reader getNCharacterStream(String arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getNClob(int)
     */
    public NClob getNClob(int arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getNClob(java.lang.String)
     */
    public NClob getNClob(String arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getNString(int)
     */
    public String getNString(int arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getNString(java.lang.String)
     */
    public String getNString(String arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getRowId(int)
     */
    public RowId getRowId(int arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getRowId(java.lang.String)
     */
    public RowId getRowId(String arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getSQLXML(int)
     */
    public SQLXML getSQLXML(int arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#getSQLXML(java.lang.String)
     */
    public SQLXML getSQLXML(String arg0) throws SQLException {
        return null;
    }

    /**
     * @see java.sql.ResultSet#isClosed()
     */
    public boolean isClosed() throws SQLException {
        return false;
    }

    /**
     * @see java.sql.ResultSet#updateAsciiStream(int, java.io.InputStream)
     */
    public void updateAsciiStream(int arg0, InputStream arg1)
                                                             throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateAsciiStream(java.lang.String, java.io.InputStream)
     */
    public void updateAsciiStream(String arg0, InputStream arg1)
                                                                throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateAsciiStream(int, java.io.InputStream, long)
     */
    public void updateAsciiStream(int arg0, InputStream arg1, long arg2)
                                                                        throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateAsciiStream(java.lang.String, java.io.InputStream, long)
     */
    public void updateAsciiStream(String arg0, InputStream arg1, long arg2)
                                                                           throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateBinaryStream(int, java.io.InputStream)
     */
    public void updateBinaryStream(int arg0, InputStream arg1)
                                                              throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateBinaryStream(java.lang.String, java.io.InputStream)
     */
    public void updateBinaryStream(String arg0, InputStream arg1)
                                                                 throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateBinaryStream(int, java.io.InputStream, long)
     */
    public void updateBinaryStream(int arg0, InputStream arg1, long arg2)
                                                                         throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateBinaryStream(java.lang.String, java.io.InputStream, long)
     */
    public void updateBinaryStream(String arg0, InputStream arg1, long arg2)
                                                                            throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateBlob(int, java.io.InputStream)
     */
    public void updateBlob(int arg0, InputStream arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateBlob(java.lang.String, java.io.InputStream)
     */
    public void updateBlob(String arg0, InputStream arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateBlob(int, java.io.InputStream, long)
     */
    public void updateBlob(int arg0, InputStream arg1, long arg2)
                                                                 throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateBlob(java.lang.String, java.io.InputStream, long)
     */
    public void updateBlob(String arg0, InputStream arg1, long arg2)
                                                                    throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateCharacterStream(int, java.io.Reader)
     */
    public void updateCharacterStream(int arg0, Reader arg1)
                                                            throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateCharacterStream(java.lang.String, java.io.Reader)
     */
    public void updateCharacterStream(String arg0, Reader arg1)
                                                               throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateCharacterStream(int, java.io.Reader, long)
     */
    public void updateCharacterStream(int arg0, Reader arg1, long arg2)
                                                                       throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateCharacterStream(java.lang.String, java.io.Reader, long)
     */
    public void updateCharacterStream(String arg0, Reader arg1, long arg2)
                                                                          throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateClob(int, java.io.Reader)
     */
    public void updateClob(int arg0, Reader arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateClob(java.lang.String, java.io.Reader)
     */
    public void updateClob(String arg0, Reader arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateClob(int, java.io.Reader, long)
     */
    public void updateClob(int arg0, Reader arg1, long arg2)
                                                            throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateClob(java.lang.String, java.io.Reader, long)
     */
    public void updateClob(String arg0, Reader arg1, long arg2)
                                                               throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNCharacterStream(int, java.io.Reader)
     */
    public void updateNCharacterStream(int arg0, Reader arg1)
                                                             throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNCharacterStream(java.lang.String, java.io.Reader)
     */
    public void updateNCharacterStream(String arg0, Reader arg1)
                                                                throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNCharacterStream(int, java.io.Reader, long)
     */
    public void updateNCharacterStream(int arg0, Reader arg1, long arg2)
                                                                        throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNCharacterStream(java.lang.String, java.io.Reader, long)
     */
    public void updateNCharacterStream(String arg0, Reader arg1, long arg2)
                                                                           throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNClob(int, java.sql.NClob)
     */
    public void updateNClob(int arg0, NClob arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNClob(java.lang.String, java.sql.NClob)
     */
    public void updateNClob(String arg0, NClob arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNClob(int, java.io.Reader)
     */
    public void updateNClob(int arg0, Reader arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNClob(java.lang.String, java.io.Reader)
     */
    public void updateNClob(String arg0, Reader arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNClob(int, java.io.Reader, long)
     */
    public void updateNClob(int arg0, Reader arg1, long arg2)
                                                             throws SQLException {
    }

    public void updateNClob(String arg0, Reader arg1, long arg2)
                                                                throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNString(int, java.lang.String)
     */
    public void updateNString(int arg0, String arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateNString(java.lang.String, java.lang.String)
     */
    public void updateNString(String arg0, String arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateRowId(int, java.sql.RowId)
     */
    public void updateRowId(int arg0, RowId arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateRowId(java.lang.String, java.sql.RowId)
     */
    public void updateRowId(String arg0, RowId arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateSQLXML(int, java.sql.SQLXML)
     */
    public void updateSQLXML(int arg0, SQLXML arg1) throws SQLException {
    }

    /**
     * @see java.sql.ResultSet#updateSQLXML(java.lang.String, java.sql.SQLXML)
     */
    public void updateSQLXML(String arg0, SQLXML arg1) throws SQLException {
    }

    /**
     * @see java.sql.Wrapper#isWrapperFor(java.lang.Class)
     */
    public boolean isWrapperFor(Class<?> arg0) throws SQLException {
        return false;
    }

    /**
     * @see java.sql.Wrapper#unwrap(java.lang.Class)
     */
    public <T> T unwrap(Class<T> arg0) throws SQLException {
        return null;
    }

}
